import React from "react"
import Link from "next/link"
import { Button } from "@/components/ui/button"
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card"
import { Badge } from "@/components/ui/badge"
import {
  GraduationCap,
  FileText,
  CreditCard,
  Users,
  CheckCircle,
  ArrowRight,
  Clock,
  MessageSquare,
  Shield,
  Search,
  RefreshCw,
  Award,
} from "lucide-react"

export default function HowItWorksPage() {
  const steps = [
    {
      number: "01",
      title: "Submit Your Requirements",
      description:
        "Provide detailed information about your academic project including topic, length, deadline, and specific instructions.",
      icon: <FileText className="h-8 w-8" />,
      color: "from-blue-600 to-blue-700",
      details: [
        "Fill out our comprehensive order form",
        "Upload any supporting materials or guidelines",
        "Specify your academic level and subject area",
        "Set your preferred deadline and urgency level",
      ],
    },
    {
      number: "02",
      title: "Secure Payment Process",
      description:
        "Complete your payment through our secure PayPal integration to confirm your order and begin the writing process.",
      icon: <CreditCard className="h-8 w-8" />,
      color: "from-emerald-600 to-emerald-700",
      details: [
        "Receive instant price calculation",
        "Secure PayPal payment processing",
        "Order confirmation via email",
        "Payment protection guarantee",
      ],
    },
    {
      number: "03",
      title: "Expert Writer Assignment",
      description:
        "Our admin team carefully matches your project with a qualified writer who specializes in your subject area.",
      icon: <Users className="h-8 w-8" />,
      color: "from-amber-600 to-amber-700",
      details: [
        "PhD-qualified writer selection",
        "Subject matter expertise matching",
        "Writer profile and credentials review",
        "Direct communication channel setup",
      ],
    },
    {
      number: "04",
      title: "Research & Writing",
      description:
        "Your assigned writer conducts thorough research and crafts your academic content with precision and scholarly rigor.",
      icon: <Search className="h-8 w-8" />,
      color: "from-purple-600 to-purple-700",
      details: [
        "Comprehensive academic research",
        "Original content creation",
        "Proper citation and formatting",
        "Progress updates and communication",
      ],
    },
    {
      number: "05",
      title: "Quality Assurance",
      description:
        "Every completed work undergoes rigorous quality checks including editing, proofreading, and plagiarism detection.",
      icon: <Shield className="h-8 w-8" />,
      color: "from-red-600 to-red-700",
      details: [
        "Multi-stage editing process",
        "Plagiarism detection scanning",
        "Format and citation verification",
        "Quality standards compliance check",
      ],
    },
    {
      number: "06",
      title: "Delivery & Revisions",
      description:
        "Receive your completed work on time with unlimited revisions until you're completely satisfied with the quality.",
      icon: <CheckCircle className="h-8 w-8" />,
      color: "from-slate-600 to-slate-700",
      details: [
        "On-time delivery guarantee",
        "Secure download portal",
        "Unlimited revision requests",
        "Final approval and satisfaction",
      ],
    },
  ]

  const features = [
    {
      icon: <Clock className="h-6 w-6" />,
      title: "24/7 Support",
      description: "Round-the-clock customer support for all your questions and concerns",
    },
    {
      icon: <MessageSquare className="h-6 w-6" />,
      title: "Direct Communication",
      description: "Chat directly with your assigned writer throughout the process",
    },
    {
      icon: <RefreshCw className="h-6 w-6" />,
      title: "Unlimited Revisions",
      description: "Free revisions until your work meets your exact requirements",
    },
    {
      icon: <Award className="h-6 w-6" />,
      title: "Quality Guarantee",
      description: "100% satisfaction guarantee or your money back",
    },
  ]

  const timeline = [
    { time: "0-2 hours", action: "Order Processing", description: "Order review and writer assignment" },
    { time: "2-24 hours", action: "Research Phase", description: "Comprehensive research and planning" },
    { time: "24-72 hours", action: "Writing Process", description: "Content creation and development" },
    { time: "Final 24 hours", action: "Quality Review", description: "Editing, proofreading, and final checks" },
  ]

  return (
    <div className="min-h-screen">
      {/* Header */}
      <header className="header-academic">
        <div className="container-academic">
          <div className="flex justify-between items-center py-4">
            <Link href="/" className="flex items-center">
              <div className="w-12 h-12 bg-navy rounded-lg flex items-center justify-center book-spine">
                <GraduationCap className="h-7 w-7 text-white" />
              </div>
              <span className="ml-3 text-2xl font-bold text-navy font-merriweather">ProEssayWorks</span>
            </Link>
            <nav className="hidden md:flex space-x-8">
              <Link href="/" className="nav-academic">
                Home
              </Link>
              <Link href="/services" className="nav-academic">
                Services
              </Link>
              <Link href="/how-it-works" className="nav-academic nav-academic-active">
                How It Works
              </Link>
              <Link href="/pricing" className="nav-academic">
                Pricing
              </Link>
              <Link href="/about" className="nav-academic">
                About
              </Link>
            </nav>
            <div className="flex space-x-3">
              <Link href="/auth/login">
                <Button variant="ghost" className="nav-academic font-medium">
                  Sign In
                </Button>
              </Link>
              <Link href="/auth/register">
                <Button className="btn-academic-primary">Get Started</Button>
              </Link>
            </div>
          </div>
        </div>
      </header>

      {/* Hero Section */}
      <section className="hero-academic section-academic-large">
        <div className="container-academic text-center text-white">
          <div className="max-w-4xl mx-auto space-y-8">
            <h1 className="heading-academic-primary text-white">
              How Our Process Works
              <span className="block bg-gradient-to-r from-yellow-300 to-amber-300 bg-clip-text text-transparent mt-2">
                Simple, Secure, Scholarly
              </span>
            </h1>
            <p className="body-academic-large text-white/90">
              From order placement to final delivery, our streamlined process ensures you receive exceptional academic
              content with complete peace of mind.
            </p>
            <Link href="/auth/register?role=client">
              <Button className="btn-academic-secondary text-base px-8 py-4">
                Start Your Order
                <ArrowRight className="ml-2 h-5 w-5" />
              </Button>
            </Link>
          </div>
        </div>
      </section>

      {/* Process Steps */}
      <section className="section-academic-large paper-texture">
        <div className="container-academic">
          <div className="text-center mb-16">
            <h2 className="heading-academic-secondary mb-8">Our 6-Step Process</h2>
            <p className="body-academic-large max-w-3xl mx-auto">
              A systematic approach to academic excellence, designed to deliver outstanding results while maintaining
              the highest standards of quality and integrity.
            </p>
          </div>

          <div className="space-y-16">
            {steps.map((step, index) => (
              <div
                key={index}
                className={`flex flex-col lg:flex-row items-center gap-12 ${index % 2 === 1 ? "lg:flex-row-reverse" : ""}`}
              >
                <div className="lg:w-1/2">
                  <Card className="card-academic">
                    <CardHeader>
                      <div className="flex items-center mb-4">
                        <div
                          className={`w-16 h-16 bg-gradient-to-br ${step.color} rounded-xl flex items-center justify-center text-white mr-6`}
                        >
                          <div className="text-center">
                            <div className="text-xs font-bold mb-1">{step.number}</div>
                            {step.icon}
                          </div>
                        </div>
                        <div>
                          <CardTitle className="heading-academic-tertiary">{step.title}</CardTitle>
                          <Badge variant="outline" className="mt-2">
                            Step {step.number}
                          </Badge>
                        </div>
                      </div>
                    </CardHeader>
                    <CardContent>
                      <p className="body-academic-regular text-gray-cool mb-6">{step.description}</p>
                      <ul className="space-y-3">
                        {step.details.map((detail, detailIndex) => (
                          <li key={detailIndex} className="flex items-center">
                            <CheckCircle className="h-5 w-5 text-emerald-600 mr-3 flex-shrink-0" />
                            <span className="body-academic-small">{detail}</span>
                          </li>
                        ))}
                      </ul>
                    </CardContent>
                  </Card>
                </div>
                <div className="lg:w-1/2 text-center lg:text-left">
                  <div
                    className={`w-32 h-32 bg-gradient-to-br ${step.color} rounded-full flex items-center justify-center mx-auto lg:mx-0 mb-6 text-white shadow-2xl`}
                  >
                    <div className="text-center">
                      <div className="text-lg font-bold mb-2">{step.number}</div>
                      {React.cloneElement(step.icon, { className: "h-12 w-12" })}
                    </div>
                  </div>
                  {index < steps.length - 1 && (
                    <div className="hidden lg:block w-0.5 h-16 bg-gradient-to-b from-navy/30 to-transparent mx-auto lg:mx-16 mt-8"></div>
                  )}
                </div>
              </div>
            ))}
          </div>
        </div>
      </section>

      {/* Timeline */}
      <section className="section-academic bg-white">
        <div className="container-academic">
          <div className="text-center mb-16">
            <h2 className="heading-academic-secondary mb-8">Typical Project Timeline</h2>
            <p className="body-academic-large max-w-3xl mx-auto">
              Understanding our workflow helps you plan your academic schedule effectively.
            </p>
          </div>

          <div className="grid md:grid-cols-4 gap-8">
            {timeline.map((item, index) => (
              <Card key={index} className="card-academic text-center">
                <CardHeader>
                  <div className="w-16 h-16 bg-gradient-to-br from-navy to-navy-light rounded-lg flex items-center justify-center mx-auto mb-4 text-white">
                    <Clock className="h-8 w-8" />
                  </div>
                  <CardTitle className="text-lg font-bold text-navy">{item.time}</CardTitle>
                  <CardDescription className="font-semibold text-navy/80">{item.action}</CardDescription>
                </CardHeader>
                <CardContent>
                  <p className="body-academic-small text-gray-cool">{item.description}</p>
                </CardContent>
              </Card>
            ))}
          </div>
        </div>
      </section>

      {/* Features */}
      <section className="section-academic paper-texture">
        <div className="container-academic">
          <div className="text-center mb-16">
            <h2 className="heading-academic-secondary mb-8">Why Choose Our Process</h2>
            <p className="body-academic-large max-w-3xl mx-auto">
              Our proven methodology ensures exceptional results while providing transparency and peace of mind.
            </p>
          </div>

          <div className="grid md:grid-cols-2 lg:grid-cols-4 gap-8">
            {features.map((feature, index) => (
              <Card key={index} className="card-academic text-center">
                <CardHeader>
                  <div className="w-16 h-16 bg-gradient-to-br from-navy to-navy-light rounded-lg flex items-center justify-center mx-auto mb-6 text-white">
                    {feature.icon}
                  </div>
                  <CardTitle className="text-xl font-bold text-navy font-merriweather">{feature.title}</CardTitle>
                </CardHeader>
                <CardContent>
                  <p className="body-academic-regular text-gray-cool">{feature.description}</p>
                </CardContent>
              </Card>
            ))}
          </div>
        </div>
      </section>

      {/* FAQ Section */}
      <section className="section-academic bg-white">
        <div className="container-academic">
          <div className="text-center mb-16">
            <h2 className="heading-academic-secondary mb-8">Frequently Asked Questions</h2>
          </div>

          <div className="grid lg:grid-cols-2 gap-8 max-w-6xl mx-auto">
            <Card className="card-academic">
              <CardHeader>
                <CardTitle className="text-lg font-bold text-navy">How long does the process take?</CardTitle>
              </CardHeader>
              <CardContent>
                <p className="body-academic-regular text-gray-cool">
                  Timeline depends on your project length and deadline. Most essays are completed within 3-5 days, while
                  larger projects like dissertations may take 2-3 weeks. Rush orders can be accommodated.
                </p>
              </CardContent>
            </Card>

            <Card className="card-academic">
              <CardHeader>
                <CardTitle className="text-lg font-bold text-navy">Can I communicate with my writer?</CardTitle>
              </CardHeader>
              <CardContent>
                <p className="body-academic-regular text-gray-cool">
                  Yes! We provide a direct messaging system where you can communicate with your assigned writer, ask
                  questions, provide additional instructions, and track progress.
                </p>
              </CardContent>
            </Card>

            <Card className="card-academic">
              <CardHeader>
                <CardTitle className="text-lg font-bold text-navy">What if I need revisions?</CardTitle>
              </CardHeader>
              <CardContent>
                <p className="body-academic-regular text-gray-cool">
                  We offer unlimited free revisions within 30 days of delivery. Simply request changes through our
                  platform, and your writer will make the necessary adjustments.
                </p>
              </CardContent>
            </Card>

            <Card className="card-academic">
              <CardHeader>
                <CardTitle className="text-lg font-bold text-navy">Is my information secure?</CardTitle>
              </CardHeader>
              <CardContent>
                <p className="body-academic-regular text-gray-cool">
                  Absolutely. We use industry-standard encryption and never share your personal information. All
                  communications and transactions are completely confidential and secure.
                </p>
              </CardContent>
            </Card>
          </div>
        </div>
      </section>

      {/* CTA Section */}
      <section className="section-academic hero-academic">
        <div className="container-academic text-center text-white">
          <div className="max-w-4xl mx-auto space-y-8">
            <h2 className="heading-academic-secondary text-white">Ready to Experience Our Process?</h2>
            <p className="body-academic-large text-white/90">
              Join thousands of students who trust our proven methodology for academic success.
            </p>
            <div className="flex flex-col sm:flex-row gap-6 justify-center max-w-lg mx-auto">
              <Link href="/auth/register?role=client">
                <Button className="btn-academic-secondary text-base px-8 py-4 w-full sm:w-auto">
                  Start Your Project
                  <ArrowRight className="ml-2 h-5 w-5" />
                </Button>
              </Link>
              <Link href="/services">
                <Button
                  variant="outline"
                  className="text-base px-8 py-4 w-full sm:w-auto text-white border-white hover:bg-white hover:text-navy"
                >
                  View Services
                </Button>
              </Link>
            </div>
          </div>
        </div>
      </section>

      {/* Footer */}
      <footer className="bg-navy text-white section-academic">
        <div className="container-academic">
          <div className="grid md:grid-cols-4 gap-10">
            <div className="space-y-8">
              <div className="flex items-center">
                <div className="w-12 h-12 bg-navy-light rounded-lg flex items-center justify-center book-spine">
                  <GraduationCap className="h-7 w-7 text-white" />
                </div>
                <span className="ml-3 text-2xl font-bold font-merriweather">ProEssayWorks</span>
              </div>
              <p className="body-academic-regular text-white/80">
                Empowering academic excellence through distinguished scholarship and expert writing services.
              </p>
            </div>
            <div>
              <h3 className="text-xl font-bold mb-8 font-merriweather">Quick Links</h3>
              <ul className="space-y-4 body-academic-regular text-white/80">
                <li>
                  <Link href="/" className="hover:text-white transition-colors">
                    Home
                  </Link>
                </li>
                <li>
                  <Link href="/services" className="hover:text-white transition-colors">
                    Services
                  </Link>
                </li>
                <li>
                  <Link href="/how-it-works" className="hover:text-white transition-colors">
                    How It Works
                  </Link>
                </li>
                <li>
                  <Link href="/pricing" className="hover:text-white transition-colors">
                    Pricing
                  </Link>
                </li>
                <li>
                  <Link href="/about" className="hover:text-white transition-colors">
                    About
                  </Link>
                </li>
              </ul>
            </div>
            <div>
              <h3 className="text-xl font-bold mb-8 font-merriweather">Services</h3>
              <ul className="space-y-4 body-academic-regular text-white/80">
                <li className="hover:text-white transition-colors cursor-pointer">Research Papers</li>
                <li className="hover:text-white transition-colors cursor-pointer">Essays</li>
                <li className="hover:text-white transition-colors cursor-pointer">Dissertations</li>
                <li className="hover:text-white transition-colors cursor-pointer">Case Studies</li>
              </ul>
            </div>
            <div>
              <h3 className="text-xl font-bold mb-8 font-merriweather">Support</h3>
              <ul className="space-y-4 body-academic-regular text-white/80">
                <li className="hover:text-white transition-colors cursor-pointer">Contact Us</li>
                <li className="hover:text-white transition-colors cursor-pointer">FAQ</li>
                <li className="hover:text-white transition-colors cursor-pointer">Privacy Policy</li>
                <li className="hover:text-white transition-colors cursor-pointer">Terms of Service</li>
              </ul>
            </div>
          </div>
          <div className="border-t border-navy-light mt-16 pt-10 text-center">
            <p className="body-academic-regular text-white/70">&copy; 2024 ProEssayWorks. All rights reserved.</p>
          </div>
        </div>
      </footer>
    </div>
  )
}
